@@ -15,14 +15,11 @@ include 'File::Temp' => {
     import => [qw/ tempfile /],
 };
 
-# TODO: will this still work on Windows?
-
 include 'File::Compare' => {
     import => [qw/ compare_text /],
 };
 
-include 'Path::Class';
-
+include 'Path::Tiny';
 include 'Pod::Readme::Test';
 
 1;
